@@ -147,6 +147,13 @@ def take_the_closest(list_obj, num_insert):
     return closest_num, closest_pos
 
 
+################################################################################
+## mutable
+################################################################################
+def isclose(mutable_a, mutable_b):
+    return [math.isclose(a, b) for a, b in zip(mutable_a, mutable_b)]
+
+
 ################################################################################
 ## dictionary
 ################################################################################
